<?php
/**
 * Holds the icon library.
 *
 * (c) Dunhakdis <dunhakdis@useissuestabinstead.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 *
 * PHP Version 5.4
 *
 * @category NiftyMenuOptions\IconLibrary
 * @package  NiftyMenuOptions
 * @author   Dunhakdis Software Creatives <emailnotdisplayed@domain.tld>
 * @author   Jasper J. <emailnotdisplayed@domain.tld>
 * @license  http://opensource.org/licenses/gpl-license.php  GNU Public License
 * @version  GIT:github.com/jasperjardin/nifty-menu-options
 * @link     https://github.com/jasperjardin/nifty-menu-options
 * @since    1.0.0
 */

namespace DSC\NiftyMenuOptions;

if ( ! defined( 'ABSPATH' ) ) {
	return;
}

/**
 * Holds the icon library.
 *
 * @category NiftyMenuOptions\IconLibrary
 * @package  NiftyMenuOptions
 * @author   Dunhakdis Software Creatives <emailnotdisplayed@domain.tld>
 * @author   Jasper J. <emailnotdisplayed@domain.tld>
 * @license  http://opensource.org/licenses/gpl-license.php  GNU Public License
 * @link     https://github.com/jasperjardin/nifty-menu-options
 * @since    1.0.0
 */
final class IconLibrary {

	/**
	 * Fetch the list of icons.
	 *
	 * @since  1.0.0
	 * @uses   add_filter() Calls 'nifty_menu_options_get_icon_library_filter' hook
	 * @return array $get_icons List of icons.
	 */
	public static function GetIcons( $set_icon_library = '' ) {
		$get_icons         = '';

		$icon_libraries = self::getLibraries();

		foreach ( $icon_libraries as $icon_library => $icons ) {
			if ( ! empty( $set_icon_library ) ) {
				if ( $icon_library === $set_icon_library ) {
					$get_icons = $icons;
				}
			} else {
				$get_icons = $icon_libraries['material_icons'];
			}
		}

		return apply_filters( 'nifty_menu_options_get_icon_library_filter', $get_icons );
	}

	/**
	 * Fetch the list of Libraries.
	 *
	 * @since  1.0.0
	 * @uses   add_filter() Calls 'nifty_menu_options_add_icon_library_filter' hook
	 * @return array $icon_libraries List of icons and libraries.
	 */
	public static function getLibraries() {
		$default_libraries = array(
			'material_icons' => self::getMateriIcons(),
		);

		$icon_libraries = apply_filters(
			'nifty_menu_options_add_icon_library_filter',
			$default_libraries
		);

		return $icon_libraries;
	}

	/**
	 * Fetch the list of Libraries and their names.
	 *
	 * @since  1.0.0
	 * @return array $icon_libraries List of icons and libraries.
	 */
	public static function getLibrariesNames( $default_library ) {
		$libraries = self::getLibraries();
		$filtered_library = array();
		$library_name = '';
		$is_default = 'not_default';
		$new_default_library = array();

		foreach ( $libraries as $library => $library_icons ) {
			$library_name = str_replace( '_', ' ', $library );

			if ( $default_library === $library ) {
				$is_default = 'is_default';
				$new_default_library = array(
					'name'    => $library_name,
					'value'   => $library,
					'default' => $is_default,
				);
			} else {
				$filtered_library[$library] = array(
					'name'    => $library_name,
					'value'   => $library,
					'default' => $is_default,
				);
			}
		}

		sort( $filtered_library );

		array_unshift( $filtered_library, $new_default_library );

		return $filtered_library;
	}

	/**
	 * Fetch the list of google material icons
	 *
	 * @since  1.0.0
	 * @return array $icons List of icons.
	 */
	public static function getMateriIcons() {
		$icons = array(
			// Icon_Category Actions
			'3d_rotation'                                 => 'action',
			'accessibility'                               => 'action',
			'accessibility_new'                           => 'action',
			'accessible'                                  => 'action',
			'accessible_forward'                          => 'action',
			'account_balance'                             => 'action',
			'account_balance_wallet'                      => 'action',
			'account_box'                                 => 'action',
			'account_circle'                              => 'action',
			'add_shopping_cart'                           => 'action',
			'alarm'                                       => 'action',
			'alarm_add'                                   => 'action',
			'alarm_off'                                   => 'action',
			'alarm_on'                                    => 'action',
			'all_inbox'                                   => 'action',
			'all_out'                                     => 'action',
			'android'                                     => 'action',
			'announcement'                                => 'action',
			'arrow_right_alt'                             => 'action',
			'aspect_ratio'                                => 'action',
			'assessment'                                  => 'action',
			'assignment'                                  => 'action',
			'assignment_ind'                              => 'action',
			'assignment_late'                             => 'action',
			'assignment_return'                           => 'action',
			'assignment_returned'                         => 'action',
			'assignment_turned_in'                        => 'action',
			'autorenew'                                   => 'action',
			'backup'                                      => 'action',
			'book'                                        => 'action',
			'bookmark'                                    => 'action',
			'bookmark_border'                             => 'action',
			'bookmarks'                                   => 'action',
			'bug_report'                                  => 'action',
			'build'                                       => 'action',
			'cached'                                      => 'action',
			'calendar_today'                              => 'action',
			'calendar_view_day'                           => 'action',
			'camera_enhance'                              => 'action',
			'card_giftcard'                               => 'action',
			'card_membership'                             => 'action',
			'card_travel'                                 => 'action',
			'change_history'                              => 'action',
			'check_circle'                                => 'action',
			'check_circle_outline'                        => 'action',
			'chrome_reader_mode'                          => 'action',
			'class'                                       => 'action',
			'code'                                        => 'action',
			'commute'                                     => 'action',
			'compare_arrows'                              => 'action',
			'contact_support'                             => 'action',
			'copyright'                                   => 'action',
			'credit_card'                                 => 'action',
			'dashboard'                                   => 'action',
			'date_range'                                  => 'action',
			'delete'                                      => 'action',
			'delete_forever'                              => 'action',
			'delete_outline'                              => 'action',
			'description'                                 => 'action',
			'dns'                                         => 'action',
			'done'                                        => 'action',
			'done_all'                                    => 'action',
			'done_outline'                                => 'action',
			'donut_large'                                 => 'action',
			'donut_small'                                 => 'action',
			'drag_indicator'                              => 'action',
			'eject'                                       => 'action',
			'euro_symbol'                                 => 'action',
			'event'                                       => 'action',
			'event_seat'                                  => 'action',
			'exit_to_app'                                 => 'action',
			'explore'                                     => 'action',
			'explore_off'                                 => 'action',
			'extension'                                   => 'action',
			'face'                                        => 'action',
			'favorite'                                    => 'action',
			'favorite_border'                             => 'action',
			'feedback'                                    => 'action',
			'find_in_page'                                => 'action',
			'find_replace'                                => 'action',
			'fingerprint'                                 => 'action',
			'flight_land'                                 => 'action',
			'flight_takeoff'                              => 'action',
			'flip_to_back'                                => 'action',
			'flip_to_front'                               => 'action',
			'g_translate'                                 => 'action',
			'gavel'                                       => 'action',
			'get_app'                                     => 'action',
			'gif'                                         => 'action',
			'grade'                                       => 'action',
			'group_work'                                  => 'action',
			'help'                                        => 'action',
			'help_outline'                                => 'action',
			'highlight_off'                               => 'action',
			'history'                                     => 'action',
			'home'                                        => 'action',
			'horizontal_split'                            => 'action',
			'hourglass_empty'                             => 'action',
			'hourglass_full'                              => 'action',
			'http'                                        => 'action',
			'https'                                       => 'action',
			'important_devices'                           => 'action',
			'info'                                        => 'action',
			'input'                                       => 'action',
			'invert_colors'                               => 'action',
			'label'                                       => 'action',
			'label_important'                             => 'action',
			'label_off'                                   => 'action',
			'language'                                    => 'action',
			'launch'                                      => 'action',
			'line_style'                                  => 'action',
			'line_weight'                                 => 'action',
			'list'                                        => 'action',
			'lock'                                        => 'action',
			'lock_open'                                   => 'action',
			'loyalty'                                     => 'action',
			'markunread_mailbox'                          => 'action',
			'maximize'                                    => 'action',
			'minimize'                                    => 'action',
			'motorcycle'                                  => 'action',
			'note_add'                                    => 'action',
			'offline_bolt'                                => 'action',
			'offline_pin'                                 => 'action',
			'opacity'                                     => 'action',
			'open_in_browser'                             => 'action',
			'open_in_new'                                 => 'action',
			'open_with'                                   => 'action',
			'pageview'                                    => 'action',
			'pan_tool'                                    => 'action',
			'payment'                                     => 'action',
			'perm_camera_mic'                             => 'action',
			'perm_contact_calendar'                       => 'action',
			'perm_data_setting'                           => 'action',
			'perm_device_information'                     => 'action',
			'perm_identity'                               => 'action',
			'perm_media'                                  => 'action',
			'perm_phone_msg'                              => 'action',
			'perm_scan_wifi'                              => 'action',
			'pets'                                        => 'action',
			'picture_in_picture'                          => 'action',
			'picture_in_picture_alt'                      => 'action',
			'play_for_work'                               => 'action',
			'polymer'                                     => 'action',
			'power_settings_new'                          => 'action',
			'pregnant_woman'                              => 'action',
			'print'                                       => 'action',
			'query_builder'                               => 'action',
			'question_answer'                             => 'action',
			'receipt'                                     => 'action',
			'record_voice_over'                           => 'action',
			'redeem'                                      => 'action',
			'remove_shopping_cart'                        => 'action',
			'reorder'                                     => 'action',
			'report_problem'                              => 'action',
			'restore'                                     => 'action',
			'restore_from_trash'                          => 'action',
			'restore_page'                                => 'action',
			'room'                                        => 'action',
			'rounded_corner'                              => 'action',
			'rowing'                                      => 'action',
			'schedule'                                    => 'action',
			'search'                                      => 'action',
			'settings'                                    => 'action',
			'settings_applications'                       => 'action',
			'settings_backup_restore'                     => 'action',
			'settings_bluetooth'                          => 'action',
			'settings_brightness'                         => 'action',
			'settings_cell'                               => 'action',
			'settings_ethernet'                           => 'action',
			'settings_input_antenna'                      => 'action',
			'settings_input_component'                    => 'action',
			'settings_input_composite'                    => 'action',
			'settings_input_hdmi'                         => 'action',
			'settings_input_svideo'                       => 'action',
			'settings_overscan'                           => 'action',
			'settings_phone'                              => 'action',
			'settings_power'                              => 'action',
			'settings_remote'                             => 'action',
			'settings_voice'                              => 'action',
			'shop'                                        => 'action',
			'shop_two'                                    => 'action',
			'shopping_basket'                             => 'action',
			'shopping_cart'                               => 'action',
			'speaker_notes'                               => 'action',
			'speaker_notes_off'                           => 'action',
			'spellcheck'                                  => 'action',
			'star_rate'                                   => 'action',
			'stars'                                       => 'action',
			'store'                                       => 'action',
			'subject'                                     => 'action',
			'supervised_user_circle'                      => 'action',
			'supervisor_account'                          => 'action',
			'swap_horiz'                                  => 'action',
			'swap_horizontal_circle'                      => 'action',
			'swap_vert'                                   => 'action',
			'swap_vertical_circle'                        => 'action',
			'tab'                                         => 'action',
			'tab_unselected'                              => 'action',
			'text_rotate_up'                              => 'action',
			'text_rotate_vertical'                        => 'action',
			'text_rotation_down'                          => 'action',
			'text_rotation_none'                          => 'action',
			'theaters'                                    => 'action',
			'thumb_down'                                  => 'action',
			'thumb_up'                                    => 'action',
			'thumbs_up_down'                              => 'action',
			'timeline'                                    => 'action',
			'toc'                                         => 'action',
			'today'                                       => 'action',
			'toll'                                        => 'action',
			'touch_app'                                   => 'action',
			'track_changes'                               => 'action',
			'translate'                                   => 'action',
			'trending_down'                               => 'action',
			'trending_flat'                               => 'action',
			'trending_up'                                 => 'action',
			'turned_in'                                   => 'action',
			'turned_in_not'                               => 'action',
			'update'                                      => 'action',
			'verified_user'                               => 'action',
			'vertical_split'                              => 'action',
			'view_agenda'                                 => 'action',
			'view_array'                                  => 'action',
			'view_carousel'                               => 'action',
			'view_column'                                 => 'action',
			'view_day'                                    => 'action',
			'view_headline'                               => 'action',
			'view_list'                                   => 'action',
			'view_module'                                 => 'action',
			'view_quilt'                                  => 'action',
			'view_stream'                                 => 'action',
			'view_week'                                   => 'action',
			'visibility'                                  => 'action',
			'visibility_off'                              => 'action',
			'voice_over_off'                              => 'action',
			'watch_later'                                 => 'action',
			'work'                                        => 'action',
			'work_off'                                    => 'action',
			'work_outline'                                => 'action',
			'youtube_searched_for'                        => 'action',
			'zoom_in'                                     => 'action',
			'zoom_out'                                    => 'action',
			// Icon_Category Alert
			'add_alert'                                   => 'alert',
			'error'                                       => 'alert',
			'error_outline'                               => 'alert',
			'notification_important'                      => 'alert',
			'warning'                                     => 'alert',
			// Icon_Category AV
			'4k'                                          => 'av',
			'add_to_queue'                                => 'av',
			'airplay'                                     => 'av',
			'album'                                       => 'av',
			'art_track'                                   => 'av',
			'av_timer'                                    => 'av',
			'branding_watermark'                          => 'av',
			'call_to_action'                              => 'av',
			'closed_caption'                              => 'av',
			'control_camera'                              => 'av',
			'equalizer'                                   => 'av',
			'explicit'                                    => 'av',
			'fast_forward'                                => 'av',
			'fast_rewind'                                 => 'av',
			'featured_play_list'                          => 'av',
			'featured_video'                              => 'av',
			'fiber_dvr'                                   => 'av',
			'fiber_manual_record'                         => 'av',
			'fiber_new'                                   => 'av',
			'fiber_pin'                                   => 'av',
			'fiber_smart_record'                          => 'av',
			'forward_10'                                  => 'av',
			'forward_30'                                  => 'av',
			'forward_5'                                   => 'av',
			'games'                                       => 'av',
			'hd'                                          => 'av',
			'hearing'                                     => 'av',
			'high_quality'                                => 'av',
			'library_add'                                 => 'av',
			'library_books'                               => 'av',
			'library_music'                               => 'av',
			'loop'                                        => 'av',
			'mic'                                         => 'av',
			'mic_none'                                    => 'av',
			'mic_off'                                     => 'av',
			'missed_video_call'                           => 'av',
			'movie'                                       => 'av',
			'music_video'                                 => 'av',
			'new_releases'                                => 'av',
			'not_interested'                              => 'av',
			'note'                                        => 'av',
			'pause'                                       => 'av',
			'pause_circle_filled'                         => 'av',
			'pause_circle_outline'                        => 'av',
			'play_arrow'                                  => 'av',
			'play_circle_filled'                          => 'av',
			'play_circle_filled_white'                    => 'av',
			'play_circle_outline'                         => 'av',
			'playlist_add'                                => 'av',
			'playlist_add_check'                          => 'av',
			'playlist_play'                               => 'av',
			'queue'                                       => 'av',
			'queue_music'                                 => 'av',
			'queue_play_next'                             => 'av',
			'radio'                                       => 'av',
			'recent_actors'                               => 'av',
			'remove_from_queue'                           => 'av',
			'repeat'                                      => 'av',
			'repeat_one'                                  => 'av',
			'replay'                                      => 'av',
			'replay_10'                                   => 'av',
			'replay_30'                                   => 'av',
			'replay_5'                                    => 'av',
			'shuffle'                                     => 'av',
			'skip_next'                                   => 'av',
			'skip_previous'                               => 'av',
			'slow_motion_video'                           => 'av',
			'snooze'                                      => 'av',
			'sort_by_alpha'                               => 'av',
			'stop'                                        => 'av',
			'subscriptions'                               => 'av',
			'subtitles'                                   => 'av',
			'surround_sound'                              => 'av',
			'video_call'                                  => 'av',
			'video_label'                                 => 'av',
			'video_library'                               => 'av',
			'videocam'                                    => 'av',
			'videocam_off'                                => 'av',
			'volume_down'                                 => 'av',
			'volume_mute'                                 => 'av',
			'volume_off'                                  => 'av',
			'volume_up'                                   => 'av',
			'web'                                         => 'av',
			'web_asset'                                   => 'av',
			// Icon_Category Communication
			'alternate_email'                             => 'communication',
			'business'                                    => 'communication',
			'call'                                        => 'communication',
			'call_end'                                    => 'communication',
			'call_made'                                   => 'communication',
			'call_merge'                                  => 'communication',
			'call_missed'                                 => 'communication',
			'call_missed_outgoing'                        => 'communication',
			'call_received'                               => 'communication',
			'call_split'                                  => 'communication',
			'cancel_presentation'                         => 'communication',
			'cell_wifi'                                   => 'communication',
			'chat'                                        => 'communication',
			'chat_bubble'                                 => 'communication',
			'chat_bubble_outline'                         => 'communication',
			'clear_all'                                   => 'communication',
			'comment'                                     => 'communication',
			'contact_mail'                                => 'communication',
			'contact_phone'                               => 'communication',
			'contacts'                                    => 'communication',
			'desktop_access_disabled'                     => 'communication',
			'dialer_sip'                                  => 'communication',
			'dialpad'                                     => 'communication',
			'domain_disabled'                             => 'communication',
			'duo'                                         => 'communication',
			'email'                                       => 'communication',
			'forum'                                       => 'communication',
			'import_contacts'                             => 'communication',
			'import_export'                               => 'communication',
			'invert_colors_off'                           => 'communication',
			'list_alt'                                    => 'communication',
			'live_help'                                   => 'communication',
			'location_off'                                => 'communication',
			'location_on'                                 => 'communication',
			'mail_outline'                                => 'communication',
			'message'                                     => 'communication',
			'mobile_screen_share'                         => 'communication',
			'no_sim'                                      => 'communication',
			'pause_presentation'                          => 'communication',
			'person_add_disabled'                         => 'communication',
			'phone'                                       => 'communication',
			'phonelink_erase'                             => 'communication',
			'phonelink_lock'                              => 'communication',
			'phonelink_ring'                              => 'communication',
			'phonelink_setup'                             => 'communication',
			'portable_wifi_off'                           => 'communication',
			'present_to_all'                              => 'communication',
			'print_disabled'                              => 'communication',
			'ring_volume'                                 => 'communication',
			'rss_feed'                                    => 'communication',
			'screen_share'                                => 'communication',
			'sentiment_satisfied_alt'                     => 'communication',
			'speaker_phone'                               => 'communication',
			'stay_current_landscape'                      => 'communication',
			'stay_current_portrait'                       => 'communication',
			'stay_primary_landscape'                      => 'communication',
			'stay_primary_portrait'                       => 'communication',
			'stop_screen_share'                           => 'communication',
			'swap_calls'                                  => 'communication',
			'textsms'                                     => 'communication',
			'unsubscribe'                                 => 'communication',
			'voicemail'                                   => 'communication',
			'vpn_key'                                     => 'communication',
			// Icon_Category Content
			'add'                                         => 'content',
			'add_box'                                     => 'content',
			'add_circle'                                  => 'content',
			'add_circle_outline'                          => 'content',
			'archive'                                     => 'content',
			'backspace'                                   => 'content',
			'ballot'                                      => 'content',
			'block'                                       => 'content',
			'clear'                                       => 'content',
			'create'                                      => 'content',
			'delete_sweep'                                => 'content',
			'drafts'                                      => 'content',
			'file_copy'                                   => 'content',
			'filter_list'                                 => 'content',
			'flag'                                        => 'content',
			'font_download'                               => 'content',
			'forward'                                     => 'content',
			'gesture'                                     => 'content',
			'how_to_reg'                                  => 'content',
			'how_to_vote'                                 => 'content',
			'inbox'                                       => 'content',
			'link'                                        => 'content',
			'link_off'                                    => 'content',
			'low_priority'                                => 'content',
			'mail'                                        => 'content',
			'markunread'                                  => 'content',
			'move_to_inbox'                               => 'content',
			'next_week'                                   => 'content',
			'outlined_flag'                               => 'content',
			'redo'                                        => 'content',
			'remove'                                      => 'content',
			'remove_circle'                               => 'content',
			'remove_circle_outline'                       => 'content',
			'reply'                                       => 'content',
			'reply_all'                                   => 'content',
			'report'                                      => 'content',
			'report_off'                                  => 'content',
			'save'                                        => 'content',
			'save_alt'                                    => 'content',
			'select_all'                                  => 'content',
			'send'                                        => 'content',
			'sort'                                        => 'content',
			'text_format'                                 => 'content',
			'unarchive'                                   => 'content',
			'undo'                                        => 'content',
			'waves'                                       => 'content',
			'weekend'                                     => 'content',
			'where_to_vote'                               => 'content',
			// Icon_Category Device
			'access_alarm'                                => 'device',
			'access_alarms'                               => 'device',
			'access_time'                                 => 'device',
			'add_alarm'                                   => 'device',
			'add_to_home_screen'                          => 'device',
			'airplanemode_active'                         => 'device',
			'airplanemode_inactive'                       => 'device',
			'battery_20'                                  => 'device',
			'battery_30'                                  => 'device',
			'battery_50'                                  => 'device',
			'battery_60'                                  => 'device',
			'battery_80'                                  => 'device',
			'battery_90'                                  => 'device',
			'battery_alert'                               => 'device',
			'battery_charging_20'                         => 'device',
			'battery_charging_30'                         => 'device',
			'battery_charging_50'                         => 'device',
			'battery_charging_60'                         => 'device',
			'battery_charging_80'                         => 'device',
			'battery_charging_90'                         => 'device',
			'battery_charging_full'                       => 'device',
			'battery_full'                                => 'device',
			'battery_std'                                 => 'device',
			'battery_unknown'                             => 'device',
			'bluetooth'                                   => 'device',
			'bluetooth_connected'                         => 'device',
			'bluetooth_disabled'                          => 'device',
			'bluetooth_searching'                         => 'device',
			'brightness_auto'                             => 'device',
			'brightness_high'                             => 'device',
			'brightness_low'                              => 'device',
			'brightness_medium'                           => 'device',
			'data_usage'                                  => 'device',
			'developer_mode'                              => 'device',
			'devices'                                     => 'device',
			'dvr'                                         => 'device',
			'gps_fixed'                                   => 'device',
			'gps_not_fixed'                               => 'device',
			'gps_off'                                     => 'device',
			'graphic_eq'                                  => 'device',
			'location_disabled'                           => 'device',
			'location_searching'                          => 'device',
			'mobile_friendly'                             => 'device',
			'mobile_off'                                  => 'device',
			'network_cell'                                => 'device',
			'network_wifi'                                => 'device',
			'nfc'                                         => 'device',
			'screen_lock_landscape'                       => 'device',
			'screen_lock_portrait'                        => 'device',
			'screen_lock_rotation'                        => 'device',
			'screen_rotation'                             => 'device',
			'sd_storage'                                  => 'device',
			'settings_system_daydream'                    => 'device',
			'signal_cellular_0_bar'                       => 'device',
			'signal_cellular_1_bar'                       => 'device',
			'signal_cellular_2_bar'                       => 'device',
			'signal_cellular_3_bar'                       => 'device',
			'signal_cellular_4_bar'                       => 'device',
			'signal_cellular_alt'                         => 'device',
			'signal_cellular_connected_no_internet_0_bar' => 'device',
			'signal_cellular_connected_no_internet_1_bar' => 'device',
			'signal_cellular_connected_no_internet_2_bar' => 'device',
			'signal_cellular_connected_no_internet_3_bar' => 'device',
			'signal_cellular_connected_no_internet_4_bar' => 'device',
			'signal_cellular_no_sim'                      => 'device',
			'signal_cellular_null'                        => 'device',
			'signal_cellular_off'                         => 'device',
			'signal_wifi_0_bar' => 'device',
			'signal_wifi_1_bar' => 'device',
			'signal_wifi_1_bar_lock' => 'device',
			'signal_wifi_2_bar' => 'device',
			'signal_wifi_2_bar_lock' => 'device',
			'signal_wifi_3_bar' => 'device',
			'signal_wifi_3_bar_lock' => 'device',
			'signal_wifi_4_bar' => 'device',
			'signal_wifi_4_bar_lock' => 'device',
			'signal_wifi_off'                             => 'device',
			'storage'                                     => 'device',
			'usb'                                         => 'device',
			'wallpaper'                                   => 'device',
			'widgets'                                     => 'device',
			'wifi_lock'                                   => 'device',
			'wifi_tethering'                              => 'device',
			// Icon_Category Editor
			'add_comment'                                 => 'editor',
			'attach_file'                                 => 'editor',
			'attach_money'                                => 'editor',
			'bar_chart'                                   => 'editor',
			'border_all'                                  => 'editor',
			'border_bottom'                               => 'editor',
			'border_clear'                                => 'editor',
			'border_color'                                => 'editor',
			'border_horizontal'                           => 'editor',
			'border_inner'                                => 'editor',
			'border_left'                                 => 'editor',
			'border_outer'                                => 'editor',
			'border_right'                                => 'editor',
			'border_style'                                => 'editor',
			'border_top'                                  => 'editor',
			'border_vertical'                             => 'editor',
			'bubble_chart'                                => 'editor',
			'drag_handle'                                 => 'editor',
			'format_align_center'                         => 'editor',
			'format_align_justify'                        => 'editor',
			'format_align_left'                           => 'editor',
			'format_align_right'                          => 'editor',
			'format_bold'                                 => 'editor',
			'format_clear'                                => 'editor',
			'format_color_fill'                           => 'editor',
			'format_color_reset'                          => 'editor',
			'format_color_text'                           => 'editor',
			'format_indent_decrease'                      => 'editor',
			'format_indent_increase'                      => 'editor',
			'format_italic'                               => 'editor',
			'format_line_spacing'                         => 'editor',
			'format_list_bulleted'                        => 'editor',
			'format_list_numbered'                        => 'editor',
			'format_list_numbered_rtl'                    => 'editor',
			'format_paint'                                => 'editor',
			'format_quote'                                => 'editor',
			'format_shapes'                               => 'editor',
			'format_size'                                 => 'editor',
			'format_strikethrough'                        => 'editor',
			'format_textdirection_l_to_r'                 => 'editor',
			'format_textdirection_r_to_l'                 => 'editor',
			'format_underlined'                           => 'editor',
			'functions'                                   => 'editor',
			'highlight'                                   => 'editor',
			'insert_chart'                                => 'editor',
			'insert_chart_outlined'                       => 'editor',
			'insert_comment'                              => 'editor',
			'insert_drive_file'                           => 'editor',
			'insert_emoticon'                             => 'editor',
			'insert_invitation'                           => 'editor',
			'insert_link'                                 => 'editor',
			'insert_photo'                                => 'editor',
			'linear_scale'                                => 'editor',
			'merge_type'                                  => 'editor',
			'mode_comment'                                => 'editor',
			'monetization_on'                             => 'editor',
			'money_off'                                   => 'editor',
			'multiline_chart'                             => 'editor',
			'notes'                                       => 'editor',
			'pie_chart'                                   => 'editor',
			'publish'                                     => 'editor',
			'scatter_plot'                                => 'editor',
			'score'                                       => 'editor',
			'short_text'                                  => 'editor',
			'show_chart'                                  => 'editor',
			'space_bar'                                   => 'editor',
			'strikethrough_s'                             => 'editor',
			'table_chart'                                 => 'editor',
			'text_fields'                                 => 'editor',
			'title'                                       => 'editor',
			'vertical_align_bottom'                       => 'editor',
			'vertical_align_center'                       => 'editor',
			'vertical_align_top'                          => 'editor',
			'wrap_text'                                   => 'editor',
			// Icon_Category File
			'attachment'                                  => 'file',
			'cloud'                                       => 'file',
			'cloud_circle'                                => 'file',
			'cloud_done'                                  => 'file',
			'cloud_download'                              => 'file',
			'cloud_off'                                   => 'file',
			'cloud_queue'                                 => 'file',
			'cloud_upload'                                => 'file',
			'create_new_folder'                           => 'file',
			'folder'                                      => 'file',
			'folder_open'                                 => 'file',
			'folder_shared'                               => 'file',
			// Icon_Category Hardware
			'cast'                                        => 'hardware',
			'cast_connected'                              => 'hardware',
			'cast_for_education'                          => 'hardware',
			'computer'                                    => 'hardware',
			'desktop_mac'                                 => 'hardware',
			'desktop_windows'                             => 'hardware',
			'developer_board'                             => 'hardware',
			'device_hub'                                  => 'hardware',
			'device_unknown'                              => 'hardware',
			'devices_other'                               => 'hardware',
			'dock'                                        => 'hardware',
			'gamepad'                                     => 'hardware',
			'headset'                                     => 'hardware',
			'headset_mic'                                 => 'hardware',
			'keyboard'                                    => 'hardware',
			'keyboard_arrow_down'                         => 'hardware',
			'keyboard_arrow_left'                         => 'hardware',
			'keyboard_arrow_right'                        => 'hardware',
			'keyboard_arrow_up'                           => 'hardware',
			'keyboard_backspace'                          => 'hardware',
			'keyboard_capslock'                           => 'hardware',
			'keyboard_hide'                               => 'hardware',
			'keyboard_return'                             => 'hardware',
			'keyboard_tab'                                => 'hardware',
			'keyboard_voice'                              => 'hardware',
			'laptop'                                      => 'hardware',
			'laptop_chromebook'                           => 'hardware',
			'laptop_mac'                                  => 'hardware',
			'laptop_windows'                              => 'hardware',
			'memory'                                      => 'hardware',
			'mouse'                                       => 'hardware',
			'phone_android'                               => 'hardware',
			'phone_iphone'                                => 'hardware',
			'phonelink'                                   => 'hardware',
			'phonelink_off'                               => 'hardware',
			'power_input'                                 => 'hardware',
			'router'                                      => 'hardware',
			'scanner'                                     => 'hardware',
			'security'                                    => 'hardware',
			'sim_card'                                    => 'hardware',
			'smartphone'                                  => 'hardware',
			'speaker'                                     => 'hardware',
			'speaker_group'                               => 'hardware',
			'tablet'                                      => 'hardware',
			'tablet_android'                              => 'hardware',
			'tablet_mac'                                  => 'hardware',
			'toys'                                        => 'hardware',
			'tv'                                          => 'hardware',
			'videogame_asset'                             => 'hardware',
			'watch'                                       => 'hardware',
			// Icon_Category Image
			'add_a_photo'                                 => 'image',
			'add_photo_alternate'                         => 'image',
			'add_to_photos'                               => 'image',
			'adjust'                                      => 'image',
			'assistant'                                   => 'image',
			'assistant_photo'                             => 'image',
			'audiotrack'                                  => 'image',
			'blur_circular'                               => 'image',
			'blur_linear'                                 => 'image',
			'blur_off'                                    => 'image',
			'blur_on'                                     => 'image',
			'brightness_1'                                => 'image',
			'brightness_2'                                => 'image',
			'brightness_3'                                => 'image',
			'brightness_4'                                => 'image',
			'brightness_5'                                => 'image',
			'brightness_6'                                => 'image',
			'brightness_7'                                => 'image',
			'broken_image'                                => 'image',
			'brush'                                       => 'image',
			'burst_mode'                                  => 'image',
			'camera'                                      => 'image',
			'camera_alt'                                  => 'image',
			'camera_front'                                => 'image',
			'camera_rear'                                 => 'image',
			'camera_roll'                                 => 'image',
			'center_focus_strong'                         => 'image',
			'center_focus_weak'                           => 'image',
			'collections'                                 => 'image',
			'collections_bookmark'                        => 'image',
			'color_lens'                                  => 'image',
			'colorize'                                    => 'image',
			'compare'                                     => 'image',
			'control_point'                               => 'image',
			'control_point_duplicate'                     => 'image',
			'crop'                                        => 'image',
			'crop_16_9'                                   => 'image',
			'crop_3_2'                                    => 'image',
			'crop_5_4'                                    => 'image',
			'crop_7_5'                                    => 'image',
			'crop_din'                                    => 'image',
			'crop_free'                                   => 'image',
			'crop_landscape'                              => 'image',
			'crop_original'                               => 'image',
			'crop_portrait'                               => 'image',
			'crop_rotate'                                 => 'image',
			'crop_square'                                 => 'image',
			'dehaze'                                      => 'image',
			'details'                                     => 'image',
			'edit'                                        => 'image',
			'exposure'                                    => 'image',
			'exposure_neg_1'                              => 'image',
			'exposure_neg_2'                              => 'image',
			'exposure_plus_1'                             => 'image',
			'exposure_plus_2'                             => 'image',
			'exposure_zero'                               => 'image',
			'filter'                                      => 'image',
			'filter_1'                                    => 'image',
			'filter_2'                                    => 'image',
			'filter_3'                                    => 'image',
			'filter_4'                                    => 'image',
			'filter_5'                                    => 'image',
			'filter_6'                                    => 'image',
			'filter_7'                                    => 'image',
			'filter_8'                                    => 'image',
			'filter_9'                                    => 'image',
			'filter_9_plus'                               => 'image',
			'filter_b_and_w'                              => 'image',
			'filter_center_focus'                         => 'image',
			'filter_drama'                                => 'image',
			'filter_frames'                               => 'image',
			'filter_hdr'                                  => 'image',
			'filter_none'                                 => 'image',
			'filter_tilt_shift'                           => 'image',
			'filter_vintage'                              => 'image',
			'flare'                                       => 'image',
			'flash_auto'                                  => 'image',
			'flash_off'                                   => 'image',
			'flash_on'                                    => 'image',
			'flip'                                        => 'image',
			'gradient'                                    => 'image',
			'grain'                                       => 'image',
			'grid_off'                                    => 'image',
			'grid_on'                                     => 'image',
			'hdr_off'                                     => 'image',
			'hdr_on'                                      => 'image',
			'hdr_strong'                                  => 'image',
			'hdr_weak'                                    => 'image',
			'healing'                                     => 'image',
			'image'                                       => 'image',
			'image_aspect_ratio'                          => 'image',
			'image_search'                                => 'image',
			'iso'                                         => 'image',
			'landscape'                                   => 'image',
			'leak_add'                                    => 'image',
			'leak_remove'                                 => 'image',
			'lens'                                        => 'image',
			'linked_camera'                               => 'image',
			'looks'                                       => 'image',
			'looks_3'                                     => 'image',
			'looks_4'                                     => 'image',
			'looks_5'                                     => 'image',
			'looks_6'                                     => 'image',
			'looks_one'                                   => 'image',
			'looks_two'                                   => 'image',
			'loupe'                                       => 'image',
			'monochrome_photos'                           => 'image',
			'movie_creation'                              => 'image',
			'movie_filter'                                => 'image',
			'music_note'                                  => 'image',
			'music_off'                                   => 'image',
			'nature'                                      => 'image',
			'nature_people'                               => 'image',
			'navigate_before'                             => 'image',
			'navigate_next'                               => 'image',
			'palette'                                     => 'image',
			'panorama'                                    => 'image',
			'panorama_fish_eye'                           => 'image',
			'panorama_horizontal'                         => 'image',
			'panorama_vertical'                           => 'image',
			'panorama_wide_angle'                         => 'image',
			'photo'                                       => 'image',
			'photo_album'                                 => 'image',
			'photo_camera'                                => 'image',
			'photo_filter'                                => 'image',
			'photo_library'                               => 'image',
			'photo_size_select_actual'                    => 'image',
			'photo_size_select_large'                     => 'image',
			'photo_size_select_small'                     => 'image',
			'picture_as_pdf'                              => 'image',
			'portrait'                                    => 'image',
			'remove_red_eye'                              => 'image',
			'rotate_90_degrees_ccw'                       => 'image',
			'rotate_left'                                 => 'image',
			'rotate_right'                                => 'image',
			'shutter_speed'                               => 'image',
			'slideshow'                                   => 'image',
			'straighten'                                  => 'image',
			'style'                                       => 'image',
			'switch_camera'                               => 'image',
			'switch_video'                                => 'image',
			'tag_faces'                                   => 'image',
			'texture'                                     => 'image',
			'timelapse'                                   => 'image',
			'timer'                                       => 'image',
			'timer_10'                                    => 'image',
			'timer_3'                                     => 'image',
			'timer_off'                                   => 'image',
			'tonality'                                    => 'image',
			'transform'                                   => 'image',
			'tune'                                        => 'image',
			'view_comfy'                                  => 'image',
			'view_compact'                                => 'image',
			'vignette'                                    => 'image',
			'wb_auto'                                     => 'image',
			'wb_cloudy'                                   => 'image',
			'wb_incandescent'                             => 'image',
			'wb_iridescent'                               => 'image',
			'wb_sunny'                                    => 'image',
			// Icon_Category Maps
			'360'                                         => 'maps',
			'add_location'                                => 'maps',
			'atm'                                         => 'maps',
			'beenhere'                                    => 'maps',
			'category'                                    => 'maps',
			'compass_calibration'                         => 'maps',
			'departure_board'                             => 'maps',
			'directions'                                  => 'maps',
			'directions_bike'                             => 'maps',
			'directions_boat'                             => 'maps',
			'directions_bus'                              => 'maps',
			'directions_car'                              => 'maps',
			'directions_railway'                          => 'maps',
			'directions_run'                              => 'maps',
			'directions_subway'                           => 'maps',
			'directions_transit'                          => 'maps',
			'directions_walk'                             => 'maps',
			'edit_attributes'                             => 'maps',
			'edit_location'                               => 'maps',
			'ev_station'                                  => 'maps',
			'fastfood'                                    => 'maps',
			'flight'                                      => 'maps',
			'hotel'                                       => 'maps',
			'layers'                                      => 'maps',
			'layers_clear'                                => 'maps',
			'local_activity'                              => 'maps',
			'local_airport'                               => 'maps',
			'local_atm'                                   => 'maps',
			'local_bar'                                   => 'maps',
			'local_cafe'                                  => 'maps',
			'local_car_wash'                              => 'maps',
			'local_convenience_store'                     => 'maps',
			'local_dining'                                => 'maps',
			'local_drink'                                 => 'maps',
			'local_florist'                               => 'maps',
			'local_gas_station'                           => 'maps',
			'local_grocery_store'                         => 'maps',
			'local_hospital'                              => 'maps',
			'local_hotel'                                 => 'maps',
			'local_laundry_service'                       => 'maps',
			'local_library'                               => 'maps',
			'local_mall'                                  => 'maps',
			'local_movies'                                => 'maps',
			'local_offer'                                 => 'maps',
			'local_parking'                               => 'maps',
			'local_pharmacy'                              => 'maps',
			'local_phone'                                 => 'maps',
			'local_pizza'                                 => 'maps',
			'local_play'                                  => 'maps',
			'local_post_office'                           => 'maps',
			'local_printshop'                             => 'maps',
			'local_see'                                   => 'maps',
			'local_shipping'                              => 'maps',
			'local_taxi'                                  => 'maps',
			'map'                                         => 'maps',
			'money'                                       => 'maps',
			'my_location'                                 => 'maps',
			'navigation'                                  => 'maps',
			'near_me'                                     => 'maps',
			'not_listed_location'                         => 'maps',
			'person_pin'                                  => 'maps',
			'person_pin_circle'                           => 'maps',
			'pin_drop'                                    => 'maps',
			'place'                                       => 'maps',
			'rate_review'                                 => 'maps',
			'restaurant'                                  => 'maps',
			'restaurant_menu'                             => 'maps',
			'satellite'                                   => 'maps',
			'store_mall_directory'                        => 'maps',
			'streetview'                                  => 'maps',
			'subway'                                      => 'maps',
			'terrain'                                     => 'maps',
			'traffic'                                     => 'maps',
			'train'                                       => 'maps',
			'tram'                                        => 'maps',
			'transfer_within_a_station'                   => 'maps',
			'transit_enterexit'                           => 'maps',
			'trip_origin'                                 => 'maps',
			'zoom_out_map'                                => 'maps',
			// Icon_Category Navigation
			'apps'                                        => 'navigation',
			'arrow_back'                                  => 'navigation',
			'arrow_back_ios'                              => 'navigation',
			'arrow_downward'                              => 'navigation',
			'arrow_drop_down'                             => 'navigation',
			'arrow_drop_down_circle'                      => 'navigation',
			'arrow_drop_up'                               => 'navigation',
			'arrow_forward'                               => 'navigation',
			'arrow_forward_ios'                           => 'navigation',
			'arrow_left'                                  => 'navigation',
			'arrow_right'                                 => 'navigation',
			'arrow_upward'                                => 'navigation',
			'cancel'                                      => 'navigation',
			'check'                                       => 'navigation',
			'chevron_left'                                => 'navigation',
			'chevron_right'                               => 'navigation',
			'close'                                       => 'navigation',
			'expand_less'                                 => 'navigation',
			'expand_more'                                 => 'navigation',
			'first_page'                                  => 'navigation',
			'fullscreen'                                  => 'navigation',
			'fullscreen_exit'                             => 'navigation',
			'last_page'                                   => 'navigation',
			'menu'                                        => 'navigation',
			'more_horiz'                                  => 'navigation',
			'more_vert'                                   => 'navigation',
			'refresh'                                     => 'navigation',
			'subdirectory_arrow_left'                     => 'navigation',
			'subdirectory_arrow_right'                    => 'navigation',
			'unfold_less'                                 => 'navigation',
			'unfold_more'                                 => 'navigation',
			// Icon_Category Notification
			'adb'                                         => 'notification',
			'airline_seat_flat'                           => 'notification',
			'airline_seat_flat_angled'                    => 'notification',
			'airline_seat_individual_suite'               => 'notification',
			'airline_seat_legroom_extra'                  => 'notification',
			'airline_seat_legroom_normal'                 => 'notification',
			'airline_seat_legroom_reduced'                => 'notification',
			'airline_seat_recline_extra'                  => 'notification',
			'airline_seat_recline_normal'                 => 'notification',
			'bluetooth_audio'                             => 'notification',
			'confirmation_number'                         => 'notification',
			'disc_full'                                   => 'notification',
			'drive_eta'                                   => 'notification',
			'enhanced_encryption'                         => 'notification',
			'event_available'                             => 'notification',
			'event_busy'                                  => 'notification',
			'event_note'                                  => 'notification',
			'folder_special'                              => 'notification',
			'live_tv'                                     => 'notification',
			'mms'                                         => 'notification',
			'more'                                        => 'notification',
			'network_check'                               => 'notification',
			'network_locked'                              => 'notification',
			'no_encryption'                               => 'notification',
			'ondemand_video'                              => 'notification',
			'personal_video'                              => 'notification',
			'phone_bluetooth_speaker'                     => 'notification',
			'phone_callback'                              => 'notification',
			'phone_forwarded'                             => 'notification',
			'phone_in_talk'                               => 'notification',
			'phone_locked'                                => 'notification',
			'phone_missed'                                => 'notification',
			'phone_paused'                                => 'notification',
			'power'                                       => 'notification',
			'power_off'                                   => 'notification',
			'priority_high'                               => 'notification',
			'sd_card'                                     => 'notification',
			'sms'                                         => 'notification',
			'sms_failed'                                  => 'notification',
			'sync'                                        => 'notification',
			'sync_disabled'                               => 'notification',
			'sync_problem'                                => 'notification',
			'system_update'                               => 'notification',
			'tap_and_play'                                => 'notification',
			'time_to_leave'                               => 'notification',
			'tv_off'                                      => 'notification',
			'vibration'                                   => 'notification',
			'voice_chat'                                  => 'notification',
			'vpn_lock'                                    => 'notification',
			'wc'                                          => 'notification',
			'wifi'                                        => 'notification',
			'wifi_off'                                    => 'notification',
			// Icon_Category Places
			'ac_unit'                                     => 'places',
			'airport_shuttle'                             => 'places',
			'all_inclusive'                               => 'places',
			'beach_access'                                => 'places',
			'business_center'                             => 'places',
			'casino'                                      => 'places',
			'child_care'                                  => 'places',
			'child_friendly'                              => 'places',
			'fitness_center'                              => 'places',
			'free_breakfast'                              => 'places',
			'golf_course'                                 => 'places',
			'hot_tub'                                     => 'places',
			'kitchen'                                     => 'places',
			'meeting_room'                                => 'places',
			'no_meeting_room'                             => 'places',
			'pool'                                        => 'places',
			'room_service'                                => 'places',
			'rv_hookup'                                   => 'places',
			'smoke_free'                                  => 'places',
			'smoking_rooms'                               => 'places',
			'spa'                                         => 'places',
			// Icon_Category Social
			'cake'                                        => 'social',
			'domain'                                      => 'social',
			'group'                                       => 'social',
			'group_add'                                   => 'social',
			'location_city'                               => 'social',
			'mood'                                        => 'social',
			'mood_bad'                                    => 'social',
			'notifications'                               => 'social',
			'notifications_active'                        => 'social',
			'notifications_none'                          => 'social',
			'notifications_off'                           => 'social',
			'notifications_paused'                        => 'social',
			'pages'                                       => 'social',
			'party_mode'                                  => 'social',
			'people'                                      => 'social',
			'people_outline'                              => 'social',
			'person'                                      => 'social',
			'person_add'                                  => 'social',
			'person_outline'                              => 'social',
			'plus_one'                                    => 'social',
			'poll'                                        => 'social',
			'public'                                      => 'social',
			'school'                                      => 'social',
			'sentiment_dissatisfied'                      => 'social',
			'sentiment_satisfied'                         => 'social',
			'sentiment_very_dissatisfied'                 => 'social',
			'sentiment_very_satisfied'                    => 'social',
			'share'                                       => 'social',
			'thumb_down_alt'                              => 'social',
			'thumb_up_alt'                                => 'social',
			'whatshot'                                    => 'social',
			// Icon_Category Toggle
			'check_box'                                   => 'toggle',
			'check_box_outline_blank'                     => 'toggle',
			'indeterminate_check_box'                     => 'toggle',
			'radio_button_checked'                        => 'toggle',
			'radio_button_unchecked'                      => 'toggle',
			'star'                                        => 'toggle',
			'star_border'                                 => 'toggle',
			'star_half'                                   => 'toggle',
			'toggle_off'                                  => 'toggle',
			'toggle_on'                                   => 'toggle',
		);
		return $icons;
	}

}
